---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: foreverallama

---

## Describe the bug
A clear and concise description of what the bug is.

## To Reproduce
Steps to reproduce the behavior:
1. Share the saved MAT-file template
2. Run ...
3. Scroll down to '....'
4. See error

## Expected behavior
A clear and concise description of what you expected to happen.

## Additional context
Add any other context about the problem here.
